@@ -3,7 +3,7 @@ import pygame
 from ESG_Engine.client.particles_emitters_manager import ParticlesEmittersManager
 from ESG_Engine.client.renderer import Renderer
 from ESG_Engine.client.sound_manager import SoundManager
-from ESG_Engine.core import Core
+from ESG_Engine.core.engine_core import Core
 from ESG_Engine.client.event_handler import EventHandler
 from ESG_Engine.client.camera import Camera
 from ESG_Engine.client.client_network import ClientNetwork
